@@ -4,12 +4,15 @@ from enrichment.knowledge_acquirer import KnowledgeAcquirer
 from colored import cprint
 
 class KnowledgeBase:
-    def __init__(self, name: str, ontology_config_file: str, knowledge_sources_config_file: str, use_neo4j: bool = False):
+    def __init__(self, name: str, ontology_config_file: str, knowledge_sources_config_file: str, use_neo4j: bool = False, disable_exa: bool = False):
         self.name = name
         self.ontology = KnowledgeOntology(ontology_config_file)
         self.graph = KnowledgeGraph(self.ontology, use_neo4j)
-        self.knowledge_acquirer = KnowledgeAcquirer(self.graph, self.ontology, knowledge_sources_config_file)
+        self.knowledge_acquirer = KnowledgeAcquirer(self.graph, self.ontology, knowledge_sources_config_file, disable_exa)
  
+
+    #TODO create external functions that can be used for non agent use case
+    
     def get_tools(self):        
         def query_tool(query: str):
             cprint(f"Querying knowledge graph", "green")
@@ -21,12 +24,11 @@ class KnowledgeBase:
         def acquire_tool(query: str): 
             cprint(f"Acquiring knowledge", "green")
             truncated_query = query[:70] + "..." if len(query) > 70 else query
-            cprint(f"Query: {truncated_query}", "yellow")
+            cprint(f"Knowledge seeked: {truncated_query}", "yellow")
             result = self.knowledge_acquirer.acquire(query)
             self.graph.update_knowledge(result)
             return result
 
-#        query_tool.__name__ = "query" 
         query_tool.__doc__ = f"""Query the knowledge graph for precise information for {self.ontology.description}
 ARGS: query: str - The query to query the knowledge graph
 RETURNS: str - The result from the knowledge graph"""
@@ -41,7 +43,6 @@ RETURNS: str - The result from the knowledge graph"""
             "required": ["query"]
         }
 
-#        acquire_tool.__name__ = "acquire"
         acquire_tool.__doc__ = f"""Acquire knowledge from the knowledge acquirer and update the knowledge graph for {self.ontology.description}
 Objective: To get high reliability and credibility information from the knowledge sources
 ARGS: query: str - The query to acquire knowledge from the knowledge acquirer
