@@ -1,6 +1,8 @@
 from graph.knowledge_graph import KnowledgeGraph
 from ontology.knowledge_ontology import KnowledgeOntology
 from enrichment.knowledge_source import KnowledgeSource
+from enrichment.function_knowledge_source.knowledge_source import FunctionKnowledgeSource
+from enrichment.mcp_knowledge_source.knowledge_source import MCPKnowledgeSource
 from utils.modelconfig import my_model
 from agno.agent import Agent
 from textwrap import dedent
@@ -10,23 +12,27 @@ import yaml
 from colored import cprint
 
 class KnowledgeAcquirer:
-    def __init__(self, graph: KnowledgeGraph, ontology: KnowledgeOntology, knowledge_sources_config_file: str):
+    def __init__(self, graph: KnowledgeGraph, ontology: KnowledgeOntology, knowledge_sources_config_file: str, disable_exa: bool = False):
         self.ontology = ontology
         self.graph = graph
         self.knowledge_sources = self.load_knowledge_sources(knowledge_sources_config_file)
-        self.tools = [ExaTools(num_results=20, summary=True)]
+        self.tools = []
+        if not disable_exa:
+            self.tools.append(ExaTools(num_results=20, summary=True))
         for source in self.knowledge_sources:
             self.tools.append(source.query_tool())
         self.tools.append(self.graph.get_tools)
+        #TODO separate acquirer agent???
         self.agent = Agent(
             name="Knowledge Acquirer",
-            role="Get high reliability and credibility information from the knowledge sources",
+            role="Enrich and update the knowledge graph with validated information from the knowledge sources",
             model=my_model,
             tools=self.tools,
+            #TODO why calling rewrite agent twice?
             instructions=self.ontology.rewrite_agent.rewrite_query(self.get_template()),
             show_tool_calls=True,
             markdown=True,
-            debug_mode=True,
+            debug_mode=False,
         )
         cprint(f"KnowledgeAcquirer initialized", "green")
 
@@ -38,10 +44,23 @@ class KnowledgeAcquirer:
         knowledge_sources = []
         with open(knowledge_sources_config_file, 'r') as file:
             knowledge_sources_config = yaml.load(file, Loader=yaml.FullLoader)
-            for source in knowledge_sources_config['knowledge_sources']:
-                source_config = knowledge_sources_config['knowledge_sources'][source]
-                source = KnowledgeSource(source_config['name'], source_config['description'], source_config['functions_file'], source_config['override_reliability'], source_config['override_credibility'])
-                knowledge_sources.append(source)
+            if knowledge_sources_config['knowledge_sources']:
+                for source in knowledge_sources_config['knowledge_sources']:
+                    if 'type' not in knowledge_sources_config['knowledge_sources'][source]: #TODO log warning
+                        raise ValueError(f"Your knowledge source config is missing the 'type' field for source: {source}")
+                    source_type = knowledge_sources_config['knowledge_sources'][source]['type']
+                    if source_type == 'function':
+                        source_config = knowledge_sources_config['knowledge_sources'][source]
+                        source = FunctionKnowledgeSource(source_config)
+                        knowledge_sources.append(source)
+                    elif source_type == 'mcp':
+                        source_config = knowledge_sources_config['knowledge_sources'][source]
+                        source = MCPKnowledgeSource(source_config)
+                        knowledge_sources.append(source)
+                    else: #TODO log warning
+                        pass
+                else: #TODO log warning
+                    pass
         return knowledge_sources
 
     def get_template(self):
